**Instalación**

    py -m pip install raxopy

**Funciones**

Por el momento, la librería tiene las funciones: 
- isprime(x), 
- isamstrong(x), 
- ispair(x),
- factorial(x), 
- tobinary(x), 
- tohexadecimal(x), 
- tooctal(x)
- createpassword(x)

**Mas información**

Si teneis alguna duda, podeis contactar al creador a través del gmail 'raxopy@gmail.com'
